==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDescriptionMetadata } from "./WebFloatingPaneResizeEventArgsDescriptionMetadata";
import { WebFloatingPaneResizeMoveEventArgsDescription } from "./WebFloatingPaneResizeMoveEventArgsDescription";
/**
 * @hidden
 */
export let WebFloatingPaneResizeMoveEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatingPaneResizeMoveEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a == null) {
                WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
            WebDockManagerPointDescriptionMetadata.d(a);
        }
        static c(a) {
            WebFloatingPaneResizeEventArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FloatingPaneResizeMoveEventArgs");
            a.item("OldWidth", "Number:double");
            a.item("NewWidth", "Number:double");
            a.item("OldHeight", "Number:double");
            a.item("NewHeight", "Number:double");
            a.item("OldLocation", "ExportedType:WebDockManagerPoint");
            a.item("NewLocation", "ExportedType:WebDockManagerPoint");
        }
        static d(a) {
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b(a);
            a.aa("WebFloatingPaneResizeMoveEventArgs", () => new WebFloatingPaneResizeMoveEventArgsDescription());
            a.z("WebFloatingPaneResizeMoveEventArgs", WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        }
    }
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, 'WebFloatingPaneResizeMoveEventArgsDescriptionMetadata');
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeMoveEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDescriptionMetadata } from "./WebFloatingPaneResizeEventArgsDescriptionMetadata";
import { WebFloatingPaneResizeMoveEventArgsDescription } from "./WebFloatingPaneResizeMoveEventArgsDescription";
/**
 * @hidden
 */
export let WebFloatingPaneResizeMoveEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatingPaneResizeMoveEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a == null) {
                WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
            WebDockManagerPointDescriptionMetadata.d(a);
        }
        static c(a) {
            WebFloatingPaneResizeEventArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FloatingPaneResizeMoveEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("OldWidth", "Number:double");
            a.item("NewWidth", "Number:double");
            a.item("OldHeight", "Number:double");
            a.item("NewHeight", "Number:double");
            a.item("OldLocation", "ExportedType:WebDockManagerPoint");
            a.item("NewLocation", "ExportedType:WebDockManagerPoint");
        }
        static d(a) {
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b(a);
            a.ac("WebFloatingPaneResizeMoveEventArgs", () => new WebFloatingPaneResizeMoveEventArgsDescription());
            a.ab("WebFloatingPaneResizeMoveEventArgs", WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        }
    }
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, 'WebFloatingPaneResizeMoveEventArgsDescriptionMetadata');
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeMoveEventArgsDescriptionMetadata;
})();
